@@ -235,5 +235,31 @@ def get_amounts_combinations(
     return df
 
 
-def price_to_tick(p):
-    return math.floor(math.log(p, 1.0001))
+def tick_to_price(tick_price, decimal_0, decimal_1):
+    tick_basis_constant = 1.0001
+    decimal_diff = decimal_0 - decimal_1
+    return 1 / (tick_basis_constant**tick_price * (10**decimal_diff))
+
+
+# def price_to_tick(p):
+#     return math.floor(math.log(p, 1.0001))
+
+
+def price_to_tick(price, decimal_0, decimal_1):
+    tick_basis_constant = 1.0001
+    decimal_diff = decimal_0 - decimal_1
+    # return int(math.ceil(math.log(1 / (price * (10 ** decimal_diff))) / math.log(tick_basis_constant)))
+    return int(
+        round(
+            math.log(1 / (price * (10**decimal_diff))) / math.log(tick_basis_constant)
+        )
+    )
+
+
+def prices_to_lower_upper_ticks(price_0, price_1, decimal_0, decimal_1):
+    ticks = price_to_tick(price_0, decimal_0, decimal_1), price_to_tick(
+        price_1, decimal_0, decimal_1
+    )
+    tick_lower = min(ticks)
+    tick_upper = max(ticks)
+    return tick_lower, tick_upper
